@@ -5,7 +5,7 @@ import click
 
 from notebooker import notebook_templates_example
 from notebooker.version import __version__
-from notebooker.constants import DEFAULT_SERIALIZER
+from notebooker.constants import DEFAULT_SERIALIZER, DEFAULT_MAILFROM_ADDRESS, DEFAULT_RUNNING_TIMEOUT
 from notebooker.execute_notebook import execute_notebook_entrypoint
 from notebooker.serialization import SERIALIZER_TO_CLI_OPTIONS
 from notebooker.settings import BaseConfig, WebappConfig
@@ -63,6 +63,17 @@ def filesystem_default_value(dirname):
     is_flag=True,
     help="If selected, notebooker will not try to pull the latest version of python templates from git.",
 )
+@click.option(
+    "--default-mailfrom",
+    default=DEFAULT_MAILFROM_ADDRESS,
+    help="Set a new value for the default mailfrom setting."
+)
+@click.option(
+    "--running-timeout",
+    default=DEFAULT_RUNNING_TIMEOUT,
+    help="Timeout in minutes for report execution",
+    type=int
+)
 @click.option(
     "--serializer-cls",
     default=DEFAULT_SERIALIZER,
@@ -77,6 +88,8 @@ def base_notebooker(
     py_template_base_dir,
     py_template_subdir,
     notebooker_disable_git,
+    default_mailfrom,
+    running_timeout,
     serializer_cls,
     **serializer_args,
 ):
@@ -89,6 +102,8 @@ def base_notebooker(
         PY_TEMPLATE_BASE_DIR=py_template_base_dir,
         PY_TEMPLATE_SUBDIR=py_template_subdir,
         NOTEBOOKER_DISABLE_GIT=notebooker_disable_git,
+        DEFAULT_MAILFROM=default_mailfrom,
+        RUNNING_TIMEOUT=running_timeout,
     )
     ctx.obj = config
 
@@ -187,6 +202,11 @@ def start_webapp(
     default=None,
     help="If available, it stores the id of the scheduler job which triggered this execution as part of the report.",
 )
+@click.option(
+    "--mailfrom",
+    default=None,
+    help="Use this email in the From header of any sent email. If not passed, --default-mailfrom will be used",
+)
 @pass_config
 def execute_notebook(
     config: BaseConfig,
@@ -203,6 +223,7 @@ def execute_notebook(
     hide_code,
     prepare_notebook_only,
     scheduler_job_id,
+    mailfrom,
 ):
     if report_name is None:
         raise ValueError("Error! Please provide a --report-name.")
@@ -221,6 +242,7 @@ def execute_notebook(
         hide_code,
         prepare_notebook_only,
         scheduler_job_id,
+        mailfrom,
     )
 
 
