@@ -79,3 +79,53 @@ function rerunReport(jobId, rerunUrl) {
 function cloneReport(cloneUrl) {
     window.location.href = cloneUrl;
 }
+
+function viewStdout(stdoutUrl) {
+    stdoutContent = document.getElementById('stdoutContent')
+
+    if (!stdoutContent.textContent) {
+        $.ajax({
+            type: 'GET',
+            url: stdoutUrl,
+            dataType: 'json',
+            success(data, status, request) {
+                stdoutContent.textContent = data.join("")
+            },
+            error(xhr, textStatus, errorThrown) {
+                $('#errorMsg').text(`${xhr.status} ${textStatus} ${errorThrown}`);
+                $('#errorPopup').show();
+            },
+        });
+    }
+
+    $('#stdoutModal').modal({
+        onDeny() {
+            return true;
+        },
+        onApprove() {
+            copy(stdoutContent.textContent)
+            return false;
+        },
+    }).modal('show');
+}
+
+function copy(text) {
+    if (navigator.clipboard && window.isSecureContext) {
+        navigator.clipboard.writeText(text);
+    } else {
+        // workaround for Chrome without https - create a hidden text area and copy from that
+        textArea = document.createElement("textarea");
+        textArea.value = text;
+
+        textArea.style.position = "absolute";
+        textArea.style.opacity = 0
+        document.body.appendChild(textArea);
+        textArea.focus();
+        textArea.select();
+
+        new Promise((res, rej) => {
+            document.execCommand('copy') ? res() : rej();
+            textArea.remove();
+        });
+    }
+}
\ No newline at end of file
